Changelog
=========

2.0.1
-----
 - updated package configuration

2.0.0
-----
 - upgraded to Pyramid 2.0

1.3.0
-----
 - merged with original ZODBBrowser 0.17

1.2.3
-----
 - updated setup

1.2.2
-----
 - updated buildout and Gitlab-CI configuration

1.2.1
-----
 - updated MyAMS modules registration

1.2.0
-----
 - ZODB browser script refactoring

1.1.0
-----
 - removed support for Python < 3.7

1.0.1
-----
 - updated Gitlab-CI configuration
 - removed Travis-CI configuration

1.0.0
-----
 - initial release
